@@ -12,6 +12,9 @@ from abc import ABC, abstractmethod
 from typing import Tuple, Optional
 
 import pygame
+# I'm hoping you can init multiple times
+pygame.init()
+
 from custom_inherit import doc_inherit
 from pygame import Color
 
@@ -35,13 +38,6 @@ class IWidgetInterface(ABC):
         """ The Widget ID, uniquely identifies each widget.
         """
 
-    @property
-    @abstractmethod
-    def neighbors(self):
-        """ The Widget's Neighbors [GO_UP, GO_DOWN, GO_LEFT, GO_RIGHT], which
-        may default to [None, None, None, None].
-        """
-
     @property
     def sub_widgets(self):
         return None
@@ -106,9 +102,9 @@ class IWidget(IWidgetInterface, ABC):
 
         Sub-classes can define any or all of the three event handlers:
 
-            on_press(Touch) -> None
-            on_release(Touch) -> Optional[Page]
-            on_move(Touch) -> None
+            _on_press(Touch) -> None
+            _on_release(Touch) -> Optional[Page]
+            _on_move(Touch) -> None
 
         where:
             `Page` : If not None, jump to that page on the next frame.
@@ -162,82 +158,68 @@ class IWidget(IWidgetInterface, ABC):
         label_color2 : Color
             Secondary color of the label; selected color
         """
-        self._id = str(uuid.uuid4()) if widget_id is None else widget_id
+        self.widget_id = widget_id or str(uuid.uuid4())
 
-        self.x, self.y = position
-        self.w, self.h = size
+        self.position = position
+        self._x, self._y = position
+
+        self.size = size
+        self._w, self._h = size
 
         # Fill in any important values not specified
-        self.label = "" if label is None else label
-        self.color1 = MEDIUM_GRAY if color1 is None else color1
-        self.color2 = WHITE if color2 is None else color2
-        self.label_color1 = WHITE if label_color1 is None else label_color1
-        self.label_color2 = BLACK if label_color2 is None else label_color2
+        self.label = label or ""
+        self.color1 = color1 or MEDIUM_GRAY
+        self.color2 = color2 or WHITE
+        self.label_color1 = label_color1 or WHITE
+        self.label_color2 = label_color2 or BLACK
+
+        self.font_size = font_size or int(min(self._w, self._h) >> 1)
 
-        self.font_size = (int(min(self.w, self.h) >> 1) if font_size is None
-                          else font_size)
         font_key = f"{FONT_NAME}:{self.font_size}"
         if font_key in self._font_cache:
             font = self._font_cache[font_key]
         else:
             font = pygame.font.Font(FONT_NAME, self.font_size)
             self._font_cache[font_key] = font
-        self.font = font
+        self._font = font
 
         self._pressed = False
         self._focus = False
+        # We can't currently serialize neighbors, as it causes infinite loops
+        # Need to develop a non-object mechanism to name neighbors
         self._neighbors = neighbors
 
-        self.touches = []
+        self._touches = []
 
         # Probe for the existence of the event handlers.
         try:
-            callable(self.on_press)
+            callable(self._on_press)
         except AttributeError:
-            self.on_press = None
+            self._on_press = None
         try:
-            callable(self.on_release)
+            callable(self._on_release)
         except AttributeError:
-            self.on_release = None
+            self._on_release = None
         try:
-            callable(self.on_move)
+            callable(self._on_move)
         except AttributeError:
-            self.on_move = None
+            self._on_move = None
         try:
-            callable(self.adjust)
+            callable(self._adjust)
         except AttributeError:
-            self.adjust = None
+            self._adjust = None
 
     @property
     def id(self):
-        return self._id
-
-    @property
-    def position(self) -> Tuple[int, int]:
-        """ The x, y top-left corner of the widget.
-        """
-        return self.x, self.y
-
-    @property
-    def size(self) -> Tuple[int, int]:
-        """ The width, height extents of the widget.
-        """
-        return self.w, self.h
+        return self.widget_id
 
     @property
     def pressed(self) -> bool:
         """ True if the widget is currently pressed.
         """
-        return len(self.touches) > 0 or self._pressed
+        return len(self._touches) > 0 or self._pressed
 
-    @property
-    def neighbors(self):
-        if self._neighbors is None:
-            self._neighbors = [None, None, None, None]
-        return self._neighbors
-
-    @neighbors.setter
-    def neighbors(self, new_neighbors):
+    def set_neighbors(self, new_neighbors):
         """ For enhanced keyboard navigation, point to the neighboring widgets.
 
         If neighbors are not specified, a more limited keyboard navigation is
@@ -287,30 +269,30 @@ class IWidget(IWidgetInterface, ABC):
             True if the touch is inside the widget extents.
         """
         x, y = touch.position
-        return (self.x <= x <= self.x + self.w and
-                self.y <= y <= self.y + self.h)
+        return (self._x <= x <= self._x + self._w and
+                self._y <= y <= self._y + self._h)
 
     def event(self, event, touch) -> Tuple[bool, Optional['Page']]:
         # PRESS
         # A press can only be registered when it is in the widget bounds
         if self.touch_inside(touch):
-            if event == TS_PRESS and touch not in self.touches:
-                self.touches.append(touch)
-                if self.on_press:
-                    return True, self.on_press(touch)
+            if event == TS_PRESS and touch not in self._touches:
+                self._touches.append(touch)
+                if self._on_press:
+                    return True, self._on_press(touch)
 
         # RELEASE
         # A touch can be released even when its not over a widget.
-        if event == TS_RELEASE and touch in self.touches:
-            self.touches.remove(touch)
-            if self.on_release:
-                return True, self.on_release(touch)
+        if event == TS_RELEASE and touch in self._touches:
+            self._touches.remove(touch)
+            if self._on_release:
+                return True, self._on_release(touch)
 
         # MOVE
         # Touch movement is tracked even when it's not over a widget
-        if event == TS_MOVE and touch in self.touches:
-            if self.on_move:
-                return True, self.on_move(touch)
+        if event == TS_MOVE and touch in self._touches:
+            if self._on_move:
+                return True, self._on_move(touch)
 
         # "Not Me" - report not consumed
         return False, None
@@ -368,10 +350,10 @@ class IWidget(IWidgetInterface, ABC):
         if text is None:
             return
 
-        text = self.font.render(text, 1, color, bg_color)
+        text = self._font.render(text, 1, color, bg_color)
         textpos = text.get_rect()
-        textpos.centerx = self.x + (self.w / 2)
-        textpos.centery = self.y + (self.h / 2)
+        textpos.centerx = self._x + (self._w / 2)
+        textpos.centery = self._y + (self._h / 2)
         surface.blit(text, textpos)
 
     def render_focus(self, surface):
@@ -381,8 +363,8 @@ class IWidget(IWidgetInterface, ABC):
         ----------
         surface : pygame.Surface
         """
-        fx, fy = self.x - 2, self.y - 2
-        fw, fh = self.w + 4, self.h + 4
+        fx, fy = self._x - 2, self._y - 2
+        fw, fh = self._w + 4, self._h + 4
         pygame.draw.rect(surface, self.focus_color(), ((fx, fy), (fw, fh)), 4)
 
 
@@ -403,7 +385,7 @@ class IButtonWidget(IWidget):
         self.function = function
         super(IButtonWidget, self).__init__(position, size, **kwargs)
 
-    def on_release(self, touch) -> Optional['Page']:
+    def _on_release(self, touch) -> Optional['Page']:
         """ Buttons always call their function on the release event.
 
         It has already been determined that the touch is inside the
@@ -477,21 +459,23 @@ class IControlWidget(IWidget, ABC):
                                              **kwargs)
 
         # Constrain the snap values to usable range
-        self.snap_value = 1 if snap_value is None else snap_value
+        self.snap_value = snap_value or 1
         self.snap_value = 0.01 if self.snap_value < 0.01 else self.snap_value
 
-        self.min_val, self.max_val = min_max
+        self.min_max = min_max
+        self._min_val, self._max_val = min_max
+
         # Value is in 0..1, where adjusted_value is in min_val..max_val
-        self.range = self.max_val - self.min_val
+        self._range = self._max_val - self._min_val
 
         if start_value is not None:
-            self.adjusted_value = start_value
-            self.value = self.normalize_adjusted_value(start_value)
+            self._adjusted_value = start_value
+            self._value = self.normalize_adjusted_value(start_value)
         else:
-            self.adjusted_value = min_max[0]
-            self.value = self.normalize_adjusted_value(min_max[0])
+            self._adjusted_value = min_max[0]
+            self._value = self.normalize_adjusted_value(min_max[0])
 
-        self.dynamic = False if dynamic is None else dynamic
+        self.dynamic = dynamic or False
 
     def map_value_to_adjusted_value(self, value) -> float:
         """ Map a value in 0..1 to an interpolated value in min_val..max_val.
@@ -506,7 +490,7 @@ class IControlWidget(IWidget, ABC):
             Widget's external value in min_val..max_val, snapped to snap_val
         """
         # map [0, 1] to [min_val, max_val] with snap
-        interp_value = float(self.min_val + (self.range * value))
+        interp_value = float(self._min_val + (self._range * value))
         return int(interp_value / self.snap_value + 0.5) * self.snap_value
 
     def normalize_adjusted_value(self, adjusted_value) -> float:
@@ -523,7 +507,7 @@ class IControlWidget(IWidget, ABC):
             Widget's internal value in 0..1
         """
         # map [min_val, max_val] to [0, 1]
-        return (adjusted_value - self.min_val) / self.range
+        return (adjusted_value - self._min_val) / self._range
 
     def value_str(self) -> str:
         """ The display version of the widget's external value.
@@ -534,9 +518,9 @@ class IControlWidget(IWidget, ABC):
             The string version of self.adjusted_value, which is the value
             the widget represents to the outside world.
         """
-        return snapped_value_string(self.adjusted_value, self.snap_value)
+        return snapped_value_string(self._adjusted_value, self.snap_value)
 
-    def on_move(self, touch):
+    def _on_move(self, touch):
         """ Controls MAY call their function on the move event.
 
         If the widget was determined to be dynamic, the function is called
@@ -548,24 +532,24 @@ class IControlWidget(IWidget, ABC):
             Touch object; generally not used for controls
         """
         if self.dynamic is True and self.function is not None:
-            return self.function(self, self.adjusted_value)
+            return self.function(self, self._adjusted_value)
 
-    def adjust(self, direction):
+    def _adjust(self, direction):
         """ Adjust the control up or down based on sign(direction)
         """
         step = math.copysign(self.snap_value, direction)
-        value = self.adjusted_value + step
-        if value < self.min_val:
-            value = self.min_val
-        elif value > self.max_val:
-            value = self.max_val
-        self.adjusted_value = value
-        self.value = self.normalize_adjusted_value(value)
+        value = self._adjusted_value + step
+        if value < self._min_val:
+            value = self._min_val
+        elif value > self._max_val:
+            value = self._max_val
+        self._adjusted_value = value
+        self._value = self.normalize_adjusted_value(value)
 
         if self.function is not None:
-            return self.function(self, self.adjusted_value)
+            return self.function(self, self._adjusted_value)
 
-    def on_release(self, touch):
+    def _on_release(self, touch):
         """ Controls call their function on the release event.
 
         It has already been determined that the touch is inside the
@@ -583,4 +567,4 @@ class IControlWidget(IWidget, ABC):
         the adjusted value.
         """
         if self.function is not None:
-            return self.function(self, self.adjusted_value)
+            return self.function(self, self._adjusted_value)
