@@ -11,6 +11,7 @@ import uuid
 from typing import Tuple, Optional
 
 import pygame
+
 from custom_inherit import doc_inherit
 
 from pi_touch_gui._widget_bases import (IButtonWidget, IWidgetInterface)
@@ -54,9 +55,9 @@ class Button(IButtonWidget):
             release).
         """
         super(Button, self).__init__(position, size, **kwargs)
-        self.style = Button.RECTANGLE if style is None else style
-        self.behavior = Button.CLICK if behavior is None else behavior
-        self.active = False
+        self.style = style or Button.RECTANGLE
+        self.behavior = behavior or Button.CLICK
+        self._active = False
 
     @doc_inherit(IButtonWidget.render, style='numpy_with_merge')
     def render(self, surface):
@@ -65,22 +66,22 @@ class Button(IButtonWidget):
         Complicated by the need for one or two rounded ends.  If you play
         your parameters right, you get a circle!
         """
-        color, label_color = self.state_colors(self.active)
+        color, label_color = self.state_colors(self._active)
 
-        radius = int(self.h / 2)
+        radius = int(self._h / 2)
         inset_x = radius if self.style & self.LEFT_ROUND else 0
         inset_w = radius if self.style & self.RIGHT_ROUND else 0
         inset_w = inset_w + inset_x
-        subrect = ((self.x + inset_x, self.y),
-                   (self.w - inset_w, self.h))
+        subrect = ((self._x + inset_x, self._y),
+                   (self._w - inset_w, self._h))
         pygame.draw.rect(surface, color, subrect, 0)
         if self.style & self.LEFT_ROUND:
             pygame.draw.circle(surface, color,
-                               (self.x + radius, self.y + radius),
+                               (self._x + radius, self._y + radius),
                                radius)
         if self.style & self.RIGHT_ROUND:
             pygame.draw.circle(surface, color,
-                               (self.x + self.w - radius, self.y + radius),
+                               (self._x + self._w - radius, self._y + radius),
                                radius)
 
         self.render_centered_text(surface, self.label, label_color, color)
@@ -90,17 +91,17 @@ class Button(IButtonWidget):
 
     def set(self):
         if self.behavior == Button.TOGGLE:
-            self.active = True
+            self._active = True
             if self.function:
-                return self.function(self, self.active)
+                return self.function(self, self._active)
 
     def clear(self):
         if self.behavior == Button.TOGGLE:
-            self.active = False
+            self._active = False
             if self.function:
-                return self.function(self, self.active)
+                return self.function(self, self._active)
 
-    def on_press(self, touch) -> None:
+    def _on_press(self, touch) -> None:
         """ Hold behavior calls their function on the press event.
 
         Parameters
@@ -112,19 +113,19 @@ class Button(IButtonWidget):
 
     def press(self):
         if self.behavior == self.HOLD:
-            self.active = True
+            self._active = True
             if self.function:
-                self.function(self, self.active)
+                self.function(self, self._active)
         super(Button, self).press()
 
-    def on_release(self, touch):
+    def _on_release(self, touch):
         return self.release()
 
     def release(self):
         if self.behavior == self.TOGGLE:
-            self.active = not self.active
+            self._active = not self._active
         else:
-            self.active = False
+            self._active = False
         return super(Button, self).release()
 
 
@@ -152,10 +153,11 @@ class ButtonGroup(IWidgetInterface):
         widget_id : str
             Optional ID for this group, if not given, gets a random uuid.
         """
-        self.label = 'group'
-        self._id = str(uuid.uuid4()) if widget_id is None else widget_id
+        self._label = 'group'
+        self.widget_id = widget_id or str(uuid.uuid4())
         self._neighbors = [None, None, None, None]
 
+        self.toggle_buttons = toggle_buttons
         self._widgets = list()
         for idx, button in enumerate(toggle_buttons):
             if not isinstance(button, Button):
@@ -196,7 +198,7 @@ class ButtonGroup(IWidgetInterface):
         # If we are enabling this button, disable all other buttons
         for b, f in self._widgets:
             if b.id != button.id:
-                b.active = False
+                b._active = False
                 if f:
                     f(b, False)
 
@@ -208,7 +210,7 @@ class ButtonGroup(IWidgetInterface):
 
     @property
     def id(self):
-        return self._id
+        return self.widget_id
 
     def event(self, event, touch) -> Tuple[bool, Optional['Page']]:
         for button, _ in self._widgets:
